@@ -11,4 +11,9 @@ from .data_structures.norm_cipher_quant import *
 from .data_structures.norm_cipher_string import *
 from .data_structures.norm_cipher_list import *
 from .data_structures.norm_cipher_frame import *
-from .data_structures.paillier_num import *
\ No newline at end of file
+from .data_structures.paillier_num import *
+
+import sys
+import warnings
+if sys.version_info < (3,8):
+    warnings.warn("WARNING.................You are using python version < 3.8\nSome of our functionality may not work as expected. Please upgrade to python 3.8 or above to avoid version errors.",DeprecationWarning)
